@@ -1,5 +1,5 @@
 # pylint: disable=arguments-differ
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, Set, Tuple
 
 from optimade.server.mappers import BaseResourceMapper as OptimadeResourceMapper
 
@@ -15,8 +15,14 @@ class ResourceMapper(OptimadeResourceMapper):
     PROJECT_PREFIX: str = "extras.optimade."
 
     TRANSLATORS: Dict[str, AiidaEntityTranslator]
-    ALL_ATTRIBUTES: set = set()
-    REQUIRED_ATTRIBUTES: set = set()
+    REQUIRED_ATTRIBUTES: Set[str] = set()
+    TOP_LEVEL_NON_ATTRIBUTES_FIELDS: Set[str] = {
+        "id",
+        "type",
+        "relationships",
+        "links",
+        "meta",
+    }
 
     @classmethod
     def all_aliases(cls) -> Tuple[Tuple[str, str]]:
@@ -26,24 +32,11 @@ class ResourceMapper(OptimadeResourceMapper):
         res = super(ResourceMapper, cls).all_aliases()
         return res + tuple(
             (field, f"{cls.PROJECT_PREFIX}{field}")
-            for field in cls.ALL_ATTRIBUTES
+            for field in set(cls.ENTRY_RESOURCE_ATTRIBUTES.keys())
+            - cls.TOP_LEVEL_NON_ATTRIBUTES_FIELDS
             if field not in dict(res)
         )
 
-    @classmethod
-    def alias_of(cls, field: str) -> str:
-        """Return de-aliased field name, if it exists,
-        otherwise return the input field name.
-
-        Args:
-            field: Field name to be de-aliased.
-
-        Returns:
-            De-aliased field name, falling back to returning `field`.
-
-        """
-        return {alias: real for real, alias in cls.all_aliases()}.get(field, field)
-
     @classmethod
     def map_back(cls, entity_properties: Dict[str, Any]) -> dict:
         """Map properties from AiiDA to OPTIMADE
@@ -64,9 +57,9 @@ class ResourceMapper(OptimadeResourceMapper):
                 )
 
         new_object = {
-            field: entity_properties[cls.alias_for(field)]
+            field: entity_properties[cls.get_backend_field(field)]
             for field in cls.TOP_LEVEL_NON_ATTRIBUTES_FIELDS
-            if cls.alias_for(field) in entity_properties
+            if cls.get_backend_field(field) in entity_properties
         }
 
         new_object["attributes"] = cls.build_attributes(
