@@ -1,10 +1,10 @@
 from typing import Dict
 import warnings
 
-from optimade.server.config import CONFIG
+from optimade.server.config import CONFIG, SupportedBackend
 
 from aiida_optimade.common import NotImplementedWarning
-from aiida_optimade.models import StructureResourceAttributes
+from aiida_optimade.models import StructureResourceAttributes, StructureResource
 from aiida_optimade.translators import (
     hex_to_floats,
     AiidaEntityTranslator,
@@ -27,9 +27,9 @@ class StructureMapper(ResourceMapper):
         "data.cif.CifData.": CifDataTranslator,
         "data.structure.StructureData.": StructureDataTranslator,
     }
-    ALL_ATTRIBUTES = set(StructureResourceAttributes.schema().get("properties").keys())
     REQUIRED_ATTRIBUTES = set(StructureResourceAttributes.schema().get("required"))
     # This should be REQUIRED_FIELDS, but should be set as such in `optimade`
+    ENTRY_RESOURCE_CLASS = StructureResource
 
     @classmethod
     def build_attributes(
@@ -63,7 +63,11 @@ class StructureMapper(ResourceMapper):
         # Add existing attributes
         existing_attributes = set(retrieved_attributes.keys())
         if missing_attributes is None:
-            missing_attributes = cls.ALL_ATTRIBUTES - existing_attributes
+            missing_attributes = (
+                cls.ALL_ATTRIBUTES
+                - cls.TOP_LEVEL_NON_ATTRIBUTES_FIELDS
+                - existing_attributes
+            )
         for field in float_fields:
             if field in existing_attributes and retrieved_attributes.get(field):
                 retrieved_attributes[field] = hex_to_floats(retrieved_attributes[field])
@@ -76,7 +80,7 @@ class StructureMapper(ResourceMapper):
                 try:
                     create_attribute = getattr(translator, attribute)
                 except AttributeError as exc:
-                    if not CONFIG.use_real_mongo:
+                    if CONFIG.database_backend != SupportedBackend.MONGODB:
                         if attribute in cls.REQUIRED_ATTRIBUTES:
                             translator = None
                             raise NotImplementedError(
@@ -102,7 +106,9 @@ class StructureMapper(ResourceMapper):
                 else:
                     res[attribute] = create_attribute()
             # Store new attributes in Node extras or MongoDB collection
-            translator.store_attributes(mongo=CONFIG.use_real_mongo)
+            translator.store_attributes(
+                mongo=CONFIG.database_backend == SupportedBackend.MONGODB
+            )
             del translator
 
         return res
